LSH_Gaussian: Creates a Neighbourhood Using Locality Sensitive Hashing for Gaussian Projections
Description
This package uses Locality Sensitive Hashing and creates a Neighbourhood Graph for a datset and calculates the ARI value for the same. It uses Gaussian Random planes to decide the nature of a given point.
Usage
LSH_Gaussian(mydata, result9)
Arguments
mydata
A data frame consisting of the data set without the class column